@@ -36,9 +36,12 @@ def get_class_name(obj):
 
 
 def getid(url):
-    matches = re.search(r'^.*/(\d+)/$', url)
     try:
-        _id = int(matches.group(1))
-        return _id
-    except ValueError:
-        return -1
+        matches = re.search(r'^.*/(\d+)/$', url)
+        if matches:
+            _id = int(matches.group(1))
+            return _id
+    except (ValueError, TypeError):
+        pass
+
+    return -1
